//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[IChitoiHandPattern](index.md)/[tiles](tiles.md)

# tiles

[common]\
open override val [tiles](tiles.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;

手牌（包括门前与副露）
